# Package-test-calculator

Description. 
This package was created as a test to better understand package creation and publication.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package-test-calculator

```bash
pip install package-test-calculator
```

## Usage

```python
from calculator import calc
calculator.add()
calculator.sub()
calculator.mult()
calculator.div()
```

## Author
VitorFran1337

## License
[MIT](https://choosealicense.com/licenses/mit/)